@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils as linux_utils
 
@@ -120,8 +121,8 @@ class TestOpenSwanDeviceDriver(test_scenario.TestIPSecBase):
 
             self.sync_to_create_ipsec_connections(site1, site2)
             # when restart_check_config is not set, start will be
-            # called in each sync
-            self.assertEqual(2, my_start.call_count)
+            # called in first sync
+            self.assertEqual(1, my_start.call_count)
             my_start.reset_mock()
 
             cfg.CONF.set_override('restart_check_config', True, group='pluto')
@@ -133,3 +134,55 @@ class TestOpenSwanDeviceDriver(test_scenario.TestIPSecBase):
             ipsec.OpenSwanProcess.active.stop()
             ipsec.OpenSwanProcess._config_changed.stop()
             cfg.CONF.set_override('restart_check_config', False, group='pluto')
+
+    def test_openswan_connection_with_non_ascii_vpnservice_name(self):
+        site1 = self.create_site(test_scenario.PUBLIC_NET[4],
+                                 [self.private_nets[1]])
+        site2 = self.create_site(test_scenario.PUBLIC_NET[5],
+                                 [self.private_nets[2]])
+        site1.vpn_service.update(
+            {'name': test_scenario.NON_ASCII_VPNSERVICE_NAME})
+
+        self.check_ping(site1, site2, success=False)
+        self.check_ping(site2, site1, success=False)
+
+        self.prepare_ipsec_site_connections(site1, site2)
+        self.sync_to_create_ipsec_connections(site1, site2)
+
+        self.check_ping(site1, site2)
+        self.check_ping(site2, site1)
+
+    def test_openswan_connection_with_non_ascii_psk(self):
+        site1 = self.create_site(test_scenario.PUBLIC_NET[4],
+                                 [self.private_nets[1]])
+        site2 = self.create_site(test_scenario.PUBLIC_NET[5],
+                                 [self.private_nets[2]])
+
+        self.check_ping(site1, site2, success=False)
+        self.check_ping(site2, site1, success=False)
+
+        self.prepare_ipsec_site_connections(site1, site2)
+        self._update_ipsec_connection(site1, psk=test_scenario.NON_ASCII_PSK)
+        self._update_ipsec_connection(site2, psk=test_scenario.NON_ASCII_PSK)
+        self.sync_to_create_ipsec_connections(site1, site2)
+
+        self.check_ping(site1, site2)
+        self.check_ping(site2, site1)
+
+    def test_openswan_connection_with_wrong_non_ascii_psk(self):
+        site1 = self.create_site(test_scenario.PUBLIC_NET[4],
+                                 [self.private_nets[1]])
+        site2 = self.create_site(test_scenario.PUBLIC_NET[5],
+                                 [self.private_nets[2]])
+
+        self.check_ping(site1, site2, success=False)
+        self.check_ping(site2, site1, success=False)
+
+        self.prepare_ipsec_site_connections(site1, site2)
+        self._update_ipsec_connection(site1, psk=test_scenario.NON_ASCII_PSK)
+        self._update_ipsec_connection(site2,
+                                      psk=test_scenario.NON_ASCII_PSK[:-1])
+        self.sync_to_create_ipsec_connections(site1, site2)
+
+        self.check_ping(site1, site2, success=False)
+        self.check_ping(site2, site1, success=False)
